about summary refs log tree commit diff
path: root/pkgs/development
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development')
-rw-r--r--pkgs/development/python-modules/pytest/default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/development/python-modules/pytest/default.nix b/pkgs/development/python-modules/pytest/default.nix
index 5fda0994010e..0e3f89fa152f 100644
--- a/pkgs/development/python-modules/pytest/default.nix
+++ b/pkgs/development/python-modules/pytest/default.nix
@@ -27,10 +27,10 @@ buildPythonPackage rec {
     runHook postCheck
   '';
 
   # Remove .pytest-cache when using py.test in a Nix build
   setupHook = writeText "pytest-hook" ''
     postFixupHooks+=(
-        'find $out -name .pytest-cache -type d -exec rm -rf {} +'
+        'find $out -name .pytest_cache -type d -exec rm -rf {} +'
     )
   '';
@@ -27,10 +27,10 @@ buildPythonPackage rec {
   '';
 
-  # Remove .pytest-cache when using py.test in a Nix build
+  # Remove .pytest_cache when using py.test in a Nix build
   setupHook = writeText "pytest-hook" ''
     postFixupHooks+=(